@@ -106,9 +106,14 @@ update_mallows.BayesMallows <- function(
 #' @rdname update_mallows
 update_mallows.SMCMallows <- function(model, new_data, ...) {
   if (length(new_data$user_ids) == 0) {
-    new_data$user_ids <- max(as.numeric(model$data$user_ids)) + seq(from = 1, to = nrow(new_data$rankings), by = 1)
+    new_data$user_ids <- max(as.numeric(model$data$user_ids)) +
+      seq(from = 1, to = nrow(new_data$rankings), by = 1)
+  }
+  if (!is.null(new_data$preferences)) {
+    new_data$preferences <- as.matrix(new_data$preferences)
+  } else {
+    new_data$preferences <- matrix(0, 0, 0)
   }
-
   ret <- run_smc(
     data = model$data,
     new_data = list(new_data),
@@ -139,9 +144,11 @@ update_mallows.SMCMallows <- function(model, new_data, ...) {
   model$rho <- tidy_parameters$rho
   model$augmented_rankings <- ret$augmented_rankings
   items <- model$data$items
-  new_constraints <- c(model$data$constraints, new_data$constraints)
+  old_constraints <- model$data$constraints[
+    setdiff(names(model$data$constraints), names(new_data$constraints))
+  ]
   model$data <- ret$data
-  model$data$constraints <- new_constraints
+  model$data$constraints <- c(old_constraints, new_data$constraints)
   model$data$items <- items
 
   class(model) <- c("SMCMallows", "BayesMallows")
