@@ -1,7 +1,7 @@
 #pragma once
 
 struct ProgressReporter{
-  ProgressReporter(bool verbose, size_t interval = 1000);
+  ProgressReporter(const Rcpp::List& progress_report);
   void report(size_t t);
 
 private:
