@@ -10,20 +10,20 @@ struct AlphaRatio{
 };
 
 AlphaRatio make_new_alpha(
-    const double& alpha_old,
+    double alpha_old,
     const arma::vec& rho_old,
-    const double& alpha_prop_sd,
+    double alpha_prop_sd,
     const std::unique_ptr<Distance>& distfun,
     const std::unique_ptr<PartitionFunction>& pfun,
     const arma::mat& rankings,
     const arma::vec& observation_frequency,
-    const double& n_items,
+    double n_items,
     const Priors& priors);
 
-arma::vec make_new_rho(
+std::pair<arma::vec, bool> make_new_rho(
     const arma::vec& current_rho,
     const arma::mat& rankings,
     double alpha_old,
-    int leap_size,
     const std::unique_ptr<Distance>& distfun,
+    const std::unique_ptr<RhoProposal>& prop,
     arma::vec observation_frequency);
